"""Top-level package for santa-helpers."""

__author__ = """Magdalena Rother"""
__email__ = 'rother.magdalena@gmail.com'
__version__ = '0.0.1'

from .neighbors import neighbors  # noqa
from .parse import parse_grid_to_dict  # noqa
